# YouTube MPV Bookmarklet

This bookmarklet allows you to play YouTube videos (and other supported sites) in MPV and automatically archive them to archive.org.

## Installation:

Drag this link to your browser's bookmarks bar:

▶️ MPV

### How to use:

1. Install the bookmarklet by dragging the button above to your bookmarks bar
2. Navigate to any YouTube video (or other supported site)
3. Click the bookmarklet
4. The video will open in MPV and be archived to archive.org

### Supported Sites:

All sites supported by yt-dlp should work, including:

- YouTube
- Vimeo
- Dailymotion
- And many more!